pub struct BitArray<T: BitStorage> { /* private fields */ }Expand description
Array of booleans as a large bit vector
Implementations
Sourceimpl<T: BitStorage> BitArray<T>
impl<T: BitStorage> BitArray<T>
Sourcepub fn new(size: usize) -> Self
pub fn new(size: usize) -> Self
Create a new bit array where the size is the expected number of bits.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Empty vector with some bytes allocated, where the size of the memory allocated depends on the underlying integer size used.
Sourcepub fn all_zeroes(&self) -> bool
pub fn all_zeroes(&self) -> bool
Indicates if none of the bits are set
Sourcepub fn iter(&self) -> BitArrayIterator<'_, T> ⓘ
pub fn iter(&self) -> BitArrayIterator<'_, T> ⓘ
Iterate over the bits in the array
Sourcepub fn get(&self, index: usize) -> bool
pub fn get(&self, index: usize) -> bool
Get the bit value from a given index
Panic
This will panic if index points to a value beyond the number of bits stored in this array.
Sourcepub fn set(&mut self, index: usize, value: bool)
pub fn set(&mut self, index: usize, value: bool)
Set the bit value at a given index
Panic
This will panic if index points to a value beyond the number of bits stored in this array.