Module unzip

Module unzip 

Logic to extract files of a specified type from a ZIP archive Functions for looking at large Zip files containing malware samples. Made with VirusShare in mind.

Structs

ZipSummaryDetails
Summary of a Zip archive’s contents

Functions

unzip_files_by_type
Unzip files of a specific type, or by all known types, from the specified ZIP archive to a destination directory Returns the number of files extracted.
zip_file_type_counts
Attempt to identify all file types contained within a zip file, returning a summary of file types and number of observations and total number of files.