pub struct ZipSummaryDetails {
pub file_type_counts: HashMap<FileTypeUnion, usize>,
pub unknown_magic_counts: HashMap<Vec<u8>, (usize, String)>,
pub total_files: usize,
}Expand description
Summary of a Zip archive’s contents
Fields
file_type_counts: HashMap<FileTypeUnion, usize>Known file types and their occurrences in the Zip archive
unknown_magic_counts: HashMap<Vec<u8>, (usize, String)>Unknown file types where their first few bytes are captured and the result from libmagic
total_files: usizeTotal number of files in the Zip archive