LogisticRegression

Struct LogisticRegression 

pub struct LogisticRegression {
    pub learning_rate: f32,
    pub bias: f32,
    pub weights: Vec<f32>,
    pub l1: f32,
    pub l2: f32,
    pub features: HashMap<Bytes, usize>,
    pub trained: bool,
    pub original_ngrams: u32,
    pub file_type: FileType,
    /* private fields */
}
Machine learning model using logistic regression

Fields

learning_rate: f32

Learning rate

bias: f32

Bias term

weights: Vec<f32>

Model’s weights

l1: f32

L1 LASSO regularization

l2: f32

L2 Ridge regularization

features: HashMap<Bytes, usize>

N-grams used to train the model

trained: bool

If the model has been trained

original_ngrams: u32

Amount of n-grams originally used

file_type: FileType

The type of file this model is trained on

Implementations

Source

impl LogisticRegression

pub fn new(input_size: usize, learning_rate: f32, l1: f32, l2: f32) -> Self

New logistic regression model with random initial weights from given parameters.

pub fn new_from_dataset_and_train( dataset: &Dataset, epochs: u32, learning_rate: f32, l1: f32, l2: f32, ) -> (Self, f32)

Returns a trained logistic regression model from given parameters and dataset. Returns the model and the error value from the last epoch.

Panics

This code won’t panic, but LogisticRegression::train would panic if the data sizes were different, but that can’t happen in this case since the same object is used in both places.

pub fn predict(&self, input: &[f32]) -> f32

Predicts the output for a given input vector. This will fail if the input vector isn’t the same length as the weights vector.

pub fn train( &mut self, epochs: u32, dataset: &Dataset, ) -> Result<f32, &'static str>

Trains the classifier once with the given inputs and outputs.

Errors

Returns an error if the data isn’t the correct size or if labels are missing.

pub fn evaluate_dataset<'a>( &self, dataset: &'a Dataset, ) -> Result<ConfusionMatrix<'a>>

Evaluate a dataset

Errors

If the dataset doesn’t match the model weight length or doesn’t have labels

pub fn evaluate_file<P: AsRef<Path>>( &self, path: P, ) -> Result<(&'static str, f32, u32)>

Evaluate a file

Errors

Errors will result if the model doesn’t have features or if the sample file can’t be read

pub fn reduce(&mut self)

Remove small weights (from regularization)

TODO: Ensure the filtered weight comparison value is sane

pub fn set_features(&mut self, features: Vec<Bytes>) -> Result<()>

Set the features by adding to the struct

Errors

Returns an error if the number of weights and features doesn’t match

pub fn with_features(self, features: Vec<Bytes>) -> Result<Self>

Set the features by creating a new struct which has the features

Errors

Returns an error if the number of weights and features doesn’t match