Logic for sorting files by type so models can then be trained on them.
Structs
- File
Sorting Results - Results of sorting files by their file type
- File
Type Union - Found file type, either a model type or a non-model type Think of this as a Union, but they aren’t safe.
Enums
- NonModel
Types - File types we’re likely to encounter, but we don’t think are good candidates for a model
Functions
- file_
sorting - Sort files by file type by creating a directory based on the file type and making a symbolic link to the original file, so no files are actually deleted.
- hash_
depth - Build up directories representing the hash but don’t include the hash itself so the directory structure can be created before adding the file to the path.
- parse_
file_ type_ union - Clap parser function for
FileTypeUniontypes. Uses Serde to get the file type from a string, uses Clap to print allowed values.