pub fn hash_depth(hash: &str, depth: u8) -> PathBuf
Build up directories representing the hash but don’t include the hash itself so the directory structure can be created before adding the file to the path.