Logic to extract files of a specified type from a ZIP archive Functions for looking at large Zip files containing malware samples. Made with VirusShare in mind.
Structs
- ZipSummary
Details - Summary of a Zip archive’s contents
Functions
- unzip_
files_ by_ type - Unzip files of a specific type, or by all known types, from the specified ZIP archive to a destination directory Returns the number of files extracted.
- zip_
file_ type_ counts - Attempt to identify all file types contained within a zip file, returning a summary of file types and number of observations and total number of files.